package javax.swing.text.html.parser;

class ContentModelState
{
    ContentModel model;
    long value;
    ContentModelState next;
    
    public ContentModelState(ContentModel contentModel) {
        this(contentModel, null, 0L);
    }
    
    ContentModelState(Object o, ContentModelState contentModelState) {
        this(o, contentModelState, 0L);
    }
    
    ContentModelState(Object o, ContentModelState next, long value) {
        this.model = (ContentModel)o;
        this.next = next;
        this.value = value;
    }
    
    public ContentModel getModel() {
        ContentModel contentModel = this.model;
        int n = 0;
        while ((long)n < this.value) {
            if (contentModel.next != null) {
                contentModel = contentModel.next;
                ++n;
            }
            else {
                return null;
            }
        }
        return contentModel;
    }
    
    public boolean terminate() {
        switch (this.model.type) {
            case 43: {
                if (this.value == 0L && !this.model.empty()) {
                    return false;
                }
            }
            case 42:
            case 63: {
                return this.next == null || this.next.terminate();
            }
            case 124: {
                ContentModel next = (ContentModel)this.model.content;
                while (next != null) {
                    if (next.empty()) {
                        return this.next == null || this.next.terminate();
                    }
                    next = next.next;
                }
                return false;
            }
            case 38: {
                ContentModel next2 = (ContentModel)this.model.content;
                int n = 0;
                while (next2 != null) {
                    if ((this.value & 1L << n) == 0x0L && !next2.empty()) {
                        return false;
                    }
                    ++n;
                    next2 = next2.next;
                }
                return this.next == null || this.next.terminate();
            }
            case 44: {
                ContentModel contentModel = (ContentModel)this.model.content;
                for (int n2 = 0; (long)n2 < this.value; ++n2, contentModel = contentModel.next) {}
                while (contentModel != null && contentModel.empty()) {
                    contentModel = contentModel.next;
                }
                return contentModel == null && (this.next == null || this.next.terminate());
            }
            default: {
                return false;
            }
        }
    }
    
    public Element first() {
        switch (this.model.type) {
            case 38:
            case 42:
            case 63:
            case 124: {
                return null;
            }
            case 43: {
                return this.model.first();
            }
            case 44: {
                ContentModel next = (ContentModel)this.model.content;
                for (int n = 0; (long)n < this.value; ++n, next = next.next) {}
                return next.first();
            }
            default: {
                return this.model.first();
            }
        }
    }
    
    public ContentModelState advance(Object o) {
        switch (this.model.type) {
            case 43: {
                if (this.model.first(o)) {
                    return new ContentModelState(this.model.content, new ContentModelState(this.model, this.next, this.value + 1L)).advance(o);
                }
                if (this.value != 0L) {
                    if (this.next != null) {
                        return this.next.advance(o);
                    }
                    return null;
                }
                else {
                    break;
                }
            }
            case 42: {
                if (this.model.first(o)) {
                    return new ContentModelState(this.model.content, this).advance(o);
                }
                if (this.next != null) {
                    return this.next.advance(o);
                }
                return null;
            }
            case 63: {
                if (this.model.first(o)) {
                    return new ContentModelState(this.model.content, this.next).advance(o);
                }
                if (this.next != null) {
                    return this.next.advance(o);
                }
                return null;
            }
            case 124: {
                ContentModel next = (ContentModel)this.model.content;
                while (next != null) {
                    if (next.first(o)) {
                        return new ContentModelState(next, this.next).advance(o);
                    }
                    next = next.next;
                }
                break;
            }
            case 44: {
                ContentModel next2 = (ContentModel)this.model.content;
                for (int n = 0; (long)n < this.value; ++n, next2 = next2.next) {}
                if (next2.first(o) || next2.empty()) {
                    if (next2.next == null) {
                        return new ContentModelState(next2, this.next).advance(o);
                    }
                    return new ContentModelState(next2, new ContentModelState(this.model, this.next, this.value + 1L)).advance(o);
                }
                else {
                    break;
                }
            }
            case 38: {
                ContentModel next3 = (ContentModel)this.model.content;
                boolean n2 = true;
                for (int n3 = 0; next3 != null; ++n3, next3 = next3.next) {
                    if ((this.value & 1L << n3) == 0x0L) {
                        if (next3.first(o)) {
                            return new ContentModelState(next3, new ContentModelState(this.model, this.next, this.value | 1L << n3)).advance(o);
                        }
                        if (!next3.empty()) {
                            n2 = false;
                        }
                    }
                }
                if (!(n2 == 0)) {
                    if (this.next != null) {
                        return this.next.advance(o);
                    }
                    return null;
                }
                else {
                    break;
                }
            }
            default: {
                if (this.model.content == o) {
                    if (this.next == null && o instanceof Element && ((Element)o).content != null) {
                        return new ContentModelState(((Element)o).content);
                    }
                    return this.next;
                }
                else {
                    break;
                }
            }
        }
        return null;
    }
}
